=============================
wagtailosm
=============================

.. image:: https://badge.fury.io/py/wagtailosm.png
    :target: http://badge.fury.io/py/wagtailosm

.. image:: https://travis-ci.org/benjaoming/wagtailosm.png?branch=master
    :target: https://travis-ci.org/benjaoming/wagtailosm


Open Street Map integration for Wagtail


Features
--------

Simple integration of OpenStreetMaps for Wagtail using the ``osm_field`` implementation. Use it as with ``osm_field``: If you want maps but don't need GIS. What it does is to maintain three columns in your database, one for latitude, one for longitude, and one for the "text search" that you have used to initially place the dot on the map in the admin.

Usage: `See docs <http://wagtailosm.readthedocs.org/en/latest/usage.html>`_.

How it looks
------------

.. image:: ./screen.png

Improvements?
-------------

This project took about 2 hours. Nothing is sacred, please contribute.

